pynoddy package — pynoddy documentation

### Navigation

- index
- modules |
- next |
- previous |
- pynoddy documentation »

# pynoddy package

## Submodules

## pynoddy.history module

Noddy history file wrapper Created on 24/03/2014

@author: Florian Wellmann

class `pynoddy.history.` `NoddyHistory`(history)

  Class container for Noddy history files

  `change_cube_size`(cube_size)

    Change the model cube size (isotropic)

    Arguments:
      - cube_size = float : new model cube size
  `determine_events`()

    Determine events and save line numbers

    Note

    Parsing of the history file is based on a fixed Noddy output order. If this is, for some reason (e.g. in a changed version of Noddy) not the case, then this parsing might fail!

  `load_history`(history)

    Load Noddy history

    Arguments:
      - history = string : Name of Noddy history file
  `write_history`(filename)

    Write history to new file

    Arguments:
      - filename = string : filename of new history file

    Hint

    Just love it how easy it is to ‘write history’ with Noddy ;-)

## pynoddy.output module

Noddy output file analysis Created on 24/03/2014

@author: Florian Wellmann

class `pynoddy.output.` `NoddyOutput`(output_name)

  Class definition for Noddy output analysis

  `export_to_vtk`(**kwds)

    Export model to VTK

    Export the geology blocks to VTK for visualisation of the entire 3-D model in an external VTK viewer, e.g. Paraview.

    ..Note:: Requires pyevtk, available for free on: https://github.com/firedrakeproject/firedrake/tree/master/python/evtk

    Optional keywords:
      - vtk_filename = string : filename of VTK file (default: output_name)
  `load_geology`()

    Load block geology ids from .g12 output file

  `load_model_info`()

    Load information about model discretisation from .g00 file

  `plot_section`(direction='y', position='center', **kwds)

    Create a section block through the model

    Arguments:

      - direction = ‘x’, ‘y’, ‘z’ : coordinate direction of section plot (default: ‘y’)

      - position = int or ‘center’ : cell position of section as integer value

          or identifier (default: ‘center’)

    Optional Keywords:
      - ax = matplotlib.axis : append plot to axis (default: create new plot)
      - figsize = (x,y) : matplotlib figsize
      - colorbar = bool : plot colorbar (default: True)
      - title = string : plot title
      - savefig = bool : save figure to file (default: show directly on scren)
      - fig_filename = string : figure filename

## Module contents

Package initialization file for pynoddy

`pynoddy.` `compute_model`(history, output_name)

### Navigation

- index
- modules |
- next |
- previous |
- pynoddy documentation »